==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1NonResourceRuleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1beta1NonResourceRuleFluent<A extends V1beta1NonResourceRuleFluent<A>> extends Fluent<A>{


    public A addToNonResourceURLs(int index,String item);
    public A setToNonResourceURLs(int index,String item);
    public A addToNonResourceURLs(String... items);
    public A addAllToNonResourceURLs(Collection<String> items);
    public A removeFromNonResourceURLs(String... items);
    public A removeAllFromNonResourceURLs(Collection<String> items);
    public List<String> getNonResourceURLs();
    public String getNonResourceURL(int index);
    public String getFirstNonResourceURL();
    public String getLastNonResourceURL();
    public String getMatchingNonResourceURL(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withNonResourceURLs(List<String> nonResourceURLs);
    public A withNonResourceURLs(String... nonResourceURLs);
    public Boolean hasNonResourceURLs();
    public A addToVerbs(int index,String item);
    public A setToVerbs(int index,String item);
    public A addToVerbs(String... items);
    public A addAllToVerbs(Collection<String> items);
    public A removeFromVerbs(String... items);
    public A removeAllFromVerbs(Collection<String> items);
    public List<String> getVerbs();
    public String getVerb(int index);
    public String getFirstVerb();
    public String getLastVerb();
    public String getMatchingVerb(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withVerbs(List<String> verbs);
    public A withVerbs(String... verbs);
    public Boolean hasVerbs();



}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1NonResourceRuleFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1beta1NonResourceRuleFluent<A extends V1beta1NonResourceRuleFluent<A>> extends Fluent<A>{


    public A addToNonResourceURLs(int index,String item);
    public A setToNonResourceURLs(int index,String item);
    public A addToNonResourceURLs(String... items);
    public A addAllToNonResourceURLs(Collection<String> items);
    public A removeFromNonResourceURLs(String... items);
    public A removeAllFromNonResourceURLs(Collection<String> items);
    public List<String> getNonResourceURLs();
    public String getNonResourceURL(int index);
    public String getFirstNonResourceURL();
    public String getLastNonResourceURL();
    public String getMatchingNonResourceURL(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingNonResourceURL(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withNonResourceURLs(List<String> nonResourceURLs);
    public A withNonResourceURLs(String... nonResourceURLs);
    public Boolean hasNonResourceURLs();
    public A addNewNonResourceURL(String arg1);
    public A addNewNonResourceURL(StringBuilder arg1);
    public A addNewNonResourceURL(StringBuffer arg1);
    public A addToVerbs(int index,String item);
    public A setToVerbs(int index,String item);
    public A addToVerbs(String... items);
    public A addAllToVerbs(Collection<String> items);
    public A removeFromVerbs(String... items);
    public A removeAllFromVerbs(Collection<String> items);
    public List<String> getVerbs();
    public String getVerb(int index);
    public String getFirstVerb();
    public String getLastVerb();
    public String getMatchingVerb(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingVerb(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withVerbs(List<String> verbs);
    public A withVerbs(String... verbs);
    public Boolean hasVerbs();
    public A addNewVerb(String arg1);
    public A addNewVerb(StringBuilder arg1);
    public A addNewVerb(StringBuffer arg1);



}
